#ifndef GRAPHICS_SCREEN_H
#define GRAPHICS_SCREEN_H TRUE

/*
**  screen.h
**
**  (C) Copyright 1996-2004 Rocklyte Systems.
**      All Rights Reserved.
*/

#ifndef MAIN_H
#include <pandora/main.h>
#endif

#ifndef GRAPHICS_BITMAP_H
#include <pandora/graphics/bitmap.h>
#endif

#ifdef __xwindows__
#include <X11/Xlib.h>
#undef NULL
#define NULL 0
#endif

/****************************************************************************
** Screen class.
*/

#define VER_SCREEN ((FLOAT)1.0)

struct Screen {
   OBJECT_HEADER           /* Standard structure header */
   LONG   Flags;           /* Special flags */
   LONG   Width;           /* The width of the visible screen */
   LONG   Height;          /* The height of the visible screen */
   LONG   XCoord;          /* Hardware co-ordinate for vertical offset */
   LONG   YCoord;          /* Hardware co-ordinate for horizontal offset */
   LONG   BmpXCoord;       /* Current offset of the horizontal axis */
   LONG   BmpYCoord;       /* Current offset of the vertical axis */
   struct Bitmap *Bitmap;  /* Bitmap */
   FLOAT  RefreshRate;     /* The active refresh rate */
   OBJECTID BufferID;      /* Double buffer bitmap */
   LONG   TotalMemory;
   LONG   DriverCertified;
   LONG   MinHScan;
   LONG   MaxHScan;
   LONG   MinVScan;
   LONG   MaxVScan;
   FLOAT  GammaRed;
   FLOAT  GammaGreen;
   FLOAT  GammaBlue;
   LONG   DisplayType;      /* DT_X11, DT_WINDOWS, DT_NATIVE */

   PRIVATE_FIELDS
   OBJECTID  prvBitmapID;
   LONG      prvBmpXOffset;   /* X offset for scrolling */
   LONG      prvBmpYOffset;   /* Y offset for scrolling */
   WINHANDLE prvWindow;
   UBYTE     prvDriverVendor[60];
   UBYTE     prvDriverCopyright[80];
   UBYTE     prvManufacturer[60];
   UBYTE     prvChipset[40];
   UBYTE     prvDAC[32];
   UBYTE     prvClock[32];
   UBYTE     prvDriverVersion[16];
   UBYTE     prvCertificationDate[20];
   UBYTE     prvDisplay[32];
   UBYTE     prvDisplayManufacturer[60];

   #ifdef _WIN32
      APTR prvOldProcedure;
   #endif

   #ifdef __snap__
      LONG prvVideoHandle;
      LONG prvGfxMode;
   #endif
};

/*****************************************************************************
** Screen Flags
*/

#define SCR_VISIBLE        0x00000001  /* Set if the Screen is on display */
#define SCR_SAVESTATE      0x00000002  /* Saves settings to the global screen state when the object is freed */
#define SCR_BUFFER         0x00000004  /* Set if you would like a complementing buffer in video RAM */
#define SCR_NOACCELERATION 0x00000008  /* 2D graphics card acceleration is not available */

#define SCR_MAXIMISE       0x80000000  /* Special win32 flag */
#define SCR_CUSTOMWINDOW   0x40000000  /* The screen has been created with a custom window reference */
#define SCR_FLIPPABLE      0x20000000  /* If SCR_BUFFER is used, this flag may be set by the display manager if it is possible to flip the buffer */
#define SCR_GTFENABLED     0x10000000  /* GTF frequency timings are supported */
#define SCR_DPMSENABLED    0x08000000  /* Power saving through DPMS is supported */
#define SCR_POWERSAVE      0x04000000  /* Power saving is active (read-only) */
#define SCR_HOSTED         0x02000000  /* The display is a hosted window in a non-Athene desktop */

enum {
   DT_NATIVE=1,
   DT_X11,
   DT_WINDOWS
};

/*****************************************************************************
** Methods
*/

#define MT_WaitVBL            -1
#define MT_UpdatePalette      -2
#define MT_SetScreenDisplay   -3
#define MT_ScreenSizeHints    -4
#define MT_SetGamma           -5
#define MT_SetGammaLinear     -6
#define MT_SetMonitor         -7

struct mtUpdatePalette { struct RGBPalette *NewPalette; };
struct mtSetGamma { DOUBLE Red; DOUBLE Green; DOUBLE Blue; LONG Flags; };
struct mtSetGammaLinear { DOUBLE Red; DOUBLE Green; DOUBLE Blue; LONG Flags; };
struct mtScreenSizeHints { LONG MinWidth; LONG MinHeight; LONG MaxWidth; LONG MaxHeight; };

struct mtSetScreenDisplay {
   LONG XCoord;
   LONG YCoord;
   LONG Width;
   LONG Height;
   LONG InsideWidth;
   LONG InsideHeight;
   LONG BitsPerPixel;
   DOUBLE RefreshRate;
   LONG Flags;
};

struct mtSetMonitor {
   STRING Name;
   LONG MinH;
   LONG MaxH;
   LONG MinV;
   LONG MaxV;
   LONG AutoDetect;
};

#define SMF_OUTPUT_CRT     0x00000001
#define SMF_OUTPUT_LCD     0x00000002
#define SMF_OUTPUT_TV      0x00000004
#define SMF_OUTPUT_DIGITAL 0x00000008

#define GMF_SAVE 0x00000001

#endif /* GRAPHICS_SCREEN_H */
